/* Created by Ville-Petteri Makinen
   email: vpmakine@gmail.com */

#include "abacus.local.h"

/*
 *
 */
string
abacus::version() {
  return ("1152.numero1");
}
